@@ -156,6 +156,7 @@ def zones_settings(self):
     self.add('AUTH', 'zones', 'settings/minify')
     self.add('AUTH', 'zones', 'settings/mirage')
     self.add('AUTH', 'zones', 'settings/mobile_redirect')
+    self.add('AUTH', 'zones', 'settings/nel')
     self.add('AUTH', 'zones', 'settings/opportunistic_encryption')
     self.add('AUTH', 'zones', 'settings/opportunistic_onion')
     self.add('AUTH', 'zones', 'settings/orange_to_orange')
@@ -185,8 +186,8 @@ def zones_analytics(self):
     """ zones analytics """
 
     self.add('VOID', 'zones', 'analytics')
-    self.add('AUTH', 'zones', 'analytics/colos')
-    self.add('AUTH', 'zones', 'analytics/dashboard')
+#   self.add('AUTH', 'zones', 'analytics/colos') # deprecated 2021-03-01 - expired!
+#   self.add('AUTH', 'zones', 'analytics/dashboard') # deprecated 2021-03-01 - expired!
     self.add('AUTH', 'zones', 'analytics/latency')
     self.add('AUTH', 'zones', 'analytics/latency/colos')
 
@@ -432,6 +433,7 @@ def accounts(self):
     self.add('VOID', 'accounts', 'workers/durable_objects')
     self.add('AUTH', 'accounts', 'workers/durable_objects/namespaces')
     self.add('AUTH', 'accounts', 'workers/durable_objects/namespaces', 'objects')
+    self.add('AUTH', 'accounts', 'workers/queues')
     self.add('AUTH', 'accounts', 'workers/scripts')
     self.add('AUTH', 'accounts', 'workers/scripts', 'schedules')
     self.add('AUTH', 'accounts', 'workers/scripts', 'tails')
@@ -549,12 +551,12 @@ def accounts_access(self):
     """ accounts access """
 
     self.add('VOID', 'accounts', 'access')
-    self.add('AUTH', 'accounts', 'access/bookmarks')
+#   self.add('AUTH', 'accounts', 'access/bookmarks') # deprecated 2023-03-19
     self.add('AUTH', 'accounts', 'access/gateway_ca')
     self.add('AUTH', 'accounts', 'access/groups')
     self.add('AUTH', 'accounts', 'access/identity_providers')
     self.add('AUTH', 'accounts', 'access/organizations')
-    self.add('AUTH', 'accounts', 'access/organizations/doh')
+#   self.add('AUTH', 'accounts', 'access/organizations/doh') # deprecated 2020-02-04 - expired!
     self.add('AUTH', 'accounts', 'access/organizations/revoke_user')
     self.add('AUTH', 'accounts', 'access/service_tokens')
     self.add('AUTH', 'accounts', 'access/service_tokens', 'refresh')
@@ -847,7 +849,7 @@ def from_developers(self):
     self.add('AUTH', 'accounts', 'analytics_engine/sql')
 
     self.add('AUTH', 'accounts', 'images/v1/config')
-    self.add('AUTH', 'accounts', 'images/v1/direct_upload')
+#   self.add('AUTH', 'accounts', 'images/v1/direct_upload') # deprecated 2022-07-01 - expired!
 
     self.add('VOID', 'accounts', 'logpush')
     self.add('AUTH', 'accounts', 'logpush/jobs')
